package com.ruoyi.mall.service.impl;

import com.ruoyi.mall.domain.OfflinePayment;
import com.ruoyi.mall.mapper.OfflinePaymentMapper;
import com.ruoyi.mall.service.IOfflinePaymentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2025-02-13
 */
@Service
public class OfflinePaymentServiceImpl implements IOfflinePaymentService {
    @Autowired
    private OfflinePaymentMapper offlinePaymentMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public OfflinePayment selectOfflinePaymentById(Long id) {
        return offlinePaymentMapper.selectOfflinePaymentById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param offlinePayment 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<OfflinePayment> selectOfflinePaymentList(OfflinePayment offlinePayment) {
        return offlinePaymentMapper.selectOfflinePaymentList(offlinePayment);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param offlinePayment 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertOfflinePayment(OfflinePayment offlinePayment) {
        return offlinePaymentMapper.insertOfflinePayment(offlinePayment);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param offlinePayment 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateOfflinePayment(OfflinePayment offlinePayment) {
        return offlinePaymentMapper.updateOfflinePayment(offlinePayment);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteOfflinePaymentByIds(Long[] ids) {
        return offlinePaymentMapper.deleteOfflinePaymentByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteOfflinePaymentById(Long id) {
        return offlinePaymentMapper.deleteOfflinePaymentById(id);
    }
}
