package com.ruoyi.web.controller.api;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.ApiResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.mall.domain.OfflinePayment;
import com.ruoyi.mall.service.IOfflinePaymentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-02-13
 */
@RestController
@RequestMapping("/api/payment")
public class ApiOfflinePaymentController extends BaseController {
    @Autowired
    private IOfflinePaymentService offlinePaymentService;

    /**
     * 查询【请填写功能名称】列表
     */

    @GetMapping("/list")
    public ApiResult list(OfflinePayment offlinePayment) {
        startPage();
        List<OfflinePayment> list = offlinePaymentService.selectOfflinePaymentList(offlinePayment);
        return ApiResult.ok().put("data",list);
    }

    /**
     * 导出【请填写功能名称】列表
     */

    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OfflinePayment offlinePayment) throws IOException {
        List<OfflinePayment> list = offlinePaymentService.selectOfflinePaymentList(offlinePayment);
        ExcelUtil<OfflinePayment> util = new ExcelUtil<OfflinePayment>(OfflinePayment.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */

    @GetMapping(value = "/{id}")
    public ApiResult getInfo(@PathVariable("id") Long id) {
        return ApiResult.ok().put("data",offlinePaymentService.selectOfflinePaymentById(id));
    }

    /**
     * 新增【请填写功能名称】
     */

    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public ApiResult add(@RequestBody OfflinePayment offlinePayment) {
        return ApiResult.ok().put("data",offlinePaymentService.insertOfflinePayment(offlinePayment));
    }

    /**
     * 修改【请填写功能名称】
     */

    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public ApiResult edit(@RequestBody OfflinePayment offlinePayment) {
        return ApiResult.ok().put("data",offlinePaymentService.updateOfflinePayment(offlinePayment));
    }

    /**
     * 删除【请填写功能名称】
     */

    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public ApiResult remove(@PathVariable Long[] ids) {
        return ApiResult.ok().put("data",offlinePaymentService.deleteOfflinePaymentByIds(ids));
    }
}
